@@ -5,7 +5,7 @@ import pandas
 import math
 import numpy
 import os
-import spams
+#import spams
 from scipy.linalg import solveh_banded
 import multiprocessing
 from operator import add, sub
